use core_rs::writer::book::XLSXBook;
use pyo3::prelude::*;
use std::sync::{Arc, Mutex};

use super::sheet::WrapperXLSXSheet;

#[pyclass]
#[pyo3(module = "core_xlsx", name = "XLSXBook")]
#[derive(Debug, Clone)]
pub struct WrapperXLSXBook(pub(crate) Arc<Mutex<XLSXBook>>);

#[pymethods]
impl WrapperXLSXBook {
    pub fn __repr__(slf: &Bound<'_, Self>) -> PyResult<String> {
        Python::with_gil(|_py| {
            let slf = slf.borrow();
            let slf_lock = slf.0.lock().unwrap();

            Ok(format!("XLSXBook, sheets: {}", slf_lock.sheets.len(),))
        })
    }

    #[new]
    pub fn new() -> Self {
        Python::with_gil(|_py| {
            let book = XLSXBook::new();

            Self(Arc::new(Mutex::new(book)))
        })
    }

    #[getter]
    pub fn sheets(&self) -> PyResult<Vec<WrapperXLSXSheet>> {
        Python::with_gil(|_py| {
            let book = self.0.lock().unwrap();
            let sheets = book
                .sheets
                .iter()
                .map(|s| WrapperXLSXSheet(Arc::clone(s)))
                .collect();

            Ok(sheets)
        })
    }

    #[pyo3(signature = (name, rows=None, cols=None))]
    pub fn add_sheet(
        &mut self,
        name: String,
        rows: Option<u32>,
        cols: Option<u16>,
    ) -> WrapperXLSXSheet {
        Python::with_gil(|_py| WrapperXLSXSheet(self.0.lock().unwrap().add_sheet(name, rows, cols)))
    }

    pub fn get_sheet_index(&self, idx: i32) -> Option<WrapperXLSXSheet> {
        self.0
            .lock()
            .unwrap()
            .get_sheet_index(idx)
            .map(|s| WrapperXLSXSheet(Arc::clone(&s)))
    }

    pub fn get_sheet_name(&self, name: String) -> Option<WrapperXLSXSheet> {
        self.0
            .lock()
            .unwrap()
            .get_sheet_name(name)
            .map(|s| WrapperXLSXSheet(Arc::clone(&s)))
    }

    pub fn to_json(&self) -> String {
        self.0.lock().unwrap().to_json()
    }
}
